@@ -1,4 +1,4 @@
-#' @title get_toggl_api_token
+#' get_toggl_api_token
 #' @description  return the toggle api token
 #' @param ask booleen do we have to ask if missing
 #' @importFrom magrittr %>% 
@@ -21,7 +21,7 @@ get_toggl_api_token <- function(ask=TRUE){
 }
 
 
-#' @title set_toggl_api_token
+#' set_toggl_api_token
 #' @description  set the toggle api token
 #' @param token toggl api token
 #' @importFrom magrittr %>% 
@@ -42,7 +42,7 @@ set_toggl_api_token <- function(token){
   token
 }
 
-#' @title update_toggl_api_token
+#' update_toggl_api_token
 #' @description  update the toggle api token
 #' @importFrom magrittr %>% 
 #' @export
@@ -59,8 +59,7 @@ delete_toggl_api_token <- function(){
 }
 
 
-#'
-#' @title ask_toggl_api_token
+#' ask_toggl_api_token
 #' @param msg the message
 #' @description  ask for the toggle api token
 #' @import getPass
@@ -80,10 +79,23 @@ ask_toggl_api_token <- function (msg="toggl api token")
 
 
 
-#' @title correct_date
+#' correct_date
 #' @description  tricks to obtain iso 8601
+#' @return time in iso 8601
 #'
 #' @param time a POSIXt
 correct_date <- function(time){
-  paste0(gsub(" ","T",as.character(time)),"+01:00")
+  if (! is.null(time)) {
+    tm <- strftime(time, "%Y-%m-%dT%H:%M:%S")
+    time_z <- strftime(time, "%z") # format +0200
+    # Add : between hour and rest
+    time_z_colon <- paste0(
+      substring(time_z, 1, 3),
+      ":",
+      substring(time_z, 4, 5))
+
+    paste0(tm, time_z_colon)
+  } else {
+    return(NULL)
+  }
 }
